@@ -6,9 +6,10 @@
  */
 
 /* eslint no-magic-numbers: 0 */
+import { Button } from "@material-ui/core";
 import React from "react";
 
-import { WebvizPluginPlaceholder, SmartNodeSelector, Menu } from "../lib";
+import { WebvizPluginPlaceholder, SmartNodeSelector, Dialog, Menu } from "../lib";
 
 const steps = [
     {
@@ -27,64 +28,74 @@ type SmartNodeSelectorProps = {
     selectedIds: string[];
 };
 
-type MenuProps = {
-    url: string;
-};
-
 const App: React.FC = () => {
-    const [
-        nodeSelectorState,
-        setNodeSelectorState,
-    ] = React.useState<SmartNodeSelectorProps>({
+    const [nodeSelectorState, setNodeSelectorState] = React.useState<SmartNodeSelectorProps>({
         selectedNodes: [],
         selectedIds: [],
         selectedTags: [],
     });
 
-    const [currentPage, setCurrentPage] = React.useState<MenuProps>({
-        url: "",
-    });
+    const [dialogOpen, setDialogOpen] = React.useState<boolean>(false);
+    const [currentPage, setCurrentPage] = React.useState<string>(window.location.hash.replace("#", ""));
 
+    React.useEffect(() => {
+        const handleLocationChange = () => {
+            setCurrentPage(window.location.hash.replace("#", ""));
+        };
+
+        window.addEventListener("popstate", handleLocationChange);
+        window.addEventListener("_dashprivate_pushstate", handleLocationChange);
+
+        return () => {
+            window.removeEventListener("popstate", handleLocationChange);
+            window.removeEventListener("_dashprivate_pushstate", handleLocationChange);
+        };
+    }, []);
     return (
         <div>
             <Menu
-                menuBarPosition="left"
-                menuDrawerPosition="left"
-                showLogo={true}
                 navigationItems={[
                     {
-                        type: "section",
-                        title: "Components",
-                        icon: "layers",
-                        content: [
-                            {
-                                type: "group",
-                                title: "Demos",
-                                content: [
-                                    {
-                                        type: "page",
-                                        title: "WebvizPluginPlaceholder",
-                                        href: "#webviz-plugin-placeholder",
-                                    },
-                                    {
-                                        type: "page",
-                                        title: "SmartNodeSelector",
-                                        href: "#smart-node-selector",
-                                    },
-                                ],
-                            },
-                        ],
+                        type: "page",
+                        title: "Dialog",
+                        href: "#dialog",
+                    },
+                    {
+                        type: "page",
+                        title: "Plugin placeholder",
+                        href: "#webviz-plugin-placeholder",
+                    },
+                    {
+                        type: "page",
+                        title: "SmartNodeSelector",
+                        href: "#smart-node-selector",
                     },
                 ]}
-                setProps={setCurrentPage}
             />
-            {currentPage.url.split("#").length === 1 && (
-                <div>
-                    <h1>webviz-core-components - Demo page</h1>Please select a
-                    component from the menu to view its demo application.
-                </div>
+            {currentPage === "dialog" && (
+                <>
+                    <h1>Dialog</h1>
+                    <Button component="button" onClick={() => setDialogOpen(true)}>
+                        Open Dialog
+                    </Button>
+                    <Dialog
+                        title="Dialog title"
+                        id="dialog"
+                        max_width="xl"
+                        open={dialogOpen}
+                        backdrop={false}
+                        draggable={true}
+                        setProps={(newProps) => {
+                            console.log(newProps);
+                            setDialogOpen(newProps.open);
+                        }}
+                        actions={["Cancel", "OK"]}
+                    >
+                        <div style={{ width: 2000 }}>This is the content of the dialog.</div>
+                    </Dialog>
+                </>
             )}
-            {currentPage.url.split("#")[1] === "webviz-plugin-placeholder" && (
+            {currentPage === "webviz-plugin-placeholder" && (
                 <>
                     <h1>WebvizPluginPlaceholder</h1>
                     <WebvizPluginPlaceholder
@@ -100,19 +111,17 @@ const App: React.FC = () => {
                         deprecation_warnings={[
                             {
                                 message: "Deprecated 1",
-                                url:
-                                    "https://github.com/equinor/webviz-core-components",
+                                url: "https://github.com/equinor/webviz-core-components",
                             },
                             {
                                 message: "Deprecated 2",
-                                url:
-                                    "https://github.com/equinor/webviz-core-components",
+                                url: "https://github.com/equinor/webviz-core-components",
                             },
                         ]}
                     />
                 </>
             )}
-            {currentPage.url.split("#")[1] === "smart-node-selector" && (
+            {currentPage === "smart-node-selector" && (
                 <>
                     <h1>SmartNodeSelector</h1>
                     <SmartNodeSelector
@@ -120,6 +129,9 @@ const App: React.FC = () => {
                         key="SmartNodeSelector"
                         numMetaNodes={2}
                         delimiter=":"
+                        placeholder="This is a very long placeholder..."
+                        selectedTags={nodeSelectorState.selectedTags}
+                        caseInsensitiveMatching={false}
                         setProps={setNodeSelectorState}
                         label="Smart Tree Node Selector"
                         data={[
@@ -139,41 +151,75 @@ const App: React.FC = () => {
                                         children: [
                                             {
                                                 id: "1.1.1",
-                                                name: "Node 1",
-                                                description:
-                                                    "A first data node",
+                                                name: "Node-1",
+                                                description: "A first data node",
                                                 children: [
                                                     {
                                                         id: "1.1.1.1",
                                                         name: "Subnode 1",
-                                                        description:
-                                                            "A first sub node",
+                                                        description: "A first sub node",
                                                     },
                                                     {
                                                         id: "1.1.1.2",
                                                         name: "Subnode 2",
-                                                        description:
-                                                            "A second sub node",
+                                                        description: "A second sub node",
                                                     },
                                                     {
                                                         id: "1.1.1.3",
                                                         name: "Subnode 3",
-                                                        description:
-                                                            "A third sub node",
+                                                        description: "A third sub node",
                                                     },
                                                     {
                                                         id: "1.1.1.4",
                                                         name: "Subnode 4",
-                                                        description:
-                                                            "A fourth sub node",
+                                                        description: "A fourth sub node",
+                                                    },
+                                                    {
+                                                        id: "1.1.1.5",
+                                                        name: "Subnode 5",
+                                                        description: "A first sub node",
+                                                    },
+                                                    {
+                                                        id: "1.1.1.6",
+                                                        name: "Subnode 6",
+                                                        description: "A second sub node",
+                                                    },
+                                                    {
+                                                        id: "1.1.1.7",
+                                                        name: "Subnode 7",
+                                                        description: "A third sub node",
+                                                    },
+                                                    {
+                                                        id: "1.1.1.8",
+                                                        name: "Subnode 8",
+                                                        description: "A fourth sub node",
+                                                    },
+                                                    {
+                                                        id: "1.1.1.9",
+                                                        name: "Subnode 9",
+                                                        description: "A first sub node",
+                                                    },
+                                                    {
+                                                        id: "1.1.1.10",
+                                                        name: "Subnode 10",
+                                                        description: "A second sub node",
+                                                    },
+                                                    {
+                                                        id: "1.1.1.11",
+                                                        name: "Subnode 11",
+                                                        description: "A third sub node",
+                                                    },
+                                                    {
+                                                        id: "1.1.1.12",
+                                                        name: "Subnode 12",
+                                                        description: "A fourth sub node",
                                                     },
                                                 ],
                                             },
                                             {
                                                 id: "1.1.2",
                                                 name: "Node 2",
-                                                description:
-                                                    "A second data node",
+                                                description: "A second data node",
                                             },
                                         ],
                                     },
@@ -204,40 +250,34 @@ const App: React.FC = () => {
                                             {
                                                 id: "2.1.1",
                                                 name: "Node 1",
-                                                description:
-                                                    "A first data node",
+                                                description: "A first data node",
                                                 children: [
                                                     {
                                                         id: "2.1.1.1",
                                                         name: "Subnode 1",
-                                                        description:
-                                                            "A first sub node",
+                                                        description: "A first sub node",
                                                     },
                                                     {
                                                         id: "2.1.1.2",
                                                         name: "Subnode 2",
-                                                        description:
-                                                            "A second sub node",
+                                                        description: "A second sub node",
                                                     },
                                                     {
                                                         id: "2.1.1.3",
                                                         name: "Subnode 3",
-                                                        description:
-                                                            "A third sub node",
+                                                        description: "A third sub node",
                                                     },
                                                     {
                                                         id: "2.1.1.4",
                                                         name: "Subnode 4",
-                                                        description:
-                                                            "A fourth sub node",
+                                                        description: "A fourth sub node",
                                                     },
                                                 ],
                                             },
                                             {
                                                 id: "2.1.2",
                                                 name: "Node 2",
-                                                description:
-                                                    "A second data node",
+                                                description: "A second data node",
                                             },
                                         ],
                                     },
@@ -256,17 +296,13 @@ const App: React.FC = () => {
                     Selected nodes:
                     <br />
                     {nodeSelectorState.selectedNodes.length > 0 &&
-                        nodeSelectorState.selectedNodes.map((node, index) => (
-                            <div key={`node-${index}`}>{node}</div>
-                        ))}
+                        nodeSelectorState.selectedNodes.map((node, index) => <div key={`node-${index}`}>{node}</div>)}
                     {nodeSelectorState.selectedNodes.length == 0 && <i>None</i>}
                     <br />
                     Selected tags:
                     <br />
                     {nodeSelectorState.selectedTags.length > 0 &&
-                        nodeSelectorState.selectedTags.map((tag, index) => (
-                            <div key={`tag-${index}`}>{tag}</div>
-                        ))}
+                        nodeSelectorState.selectedTags.map((tag, index) => <div key={`tag-${index}`}>{tag}</div>)}
                     {nodeSelectorState.selectedTags.length === 0 && <i>None</i>}
                 </>
             )}
